bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainMoments.compute_dims_from_values
=====================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: GaussianMarkovChainMoments.compute_dims_from_values